StepOutcome

Enum StepOutcome 

pub enum StepOutcome<F, R, A, Y, I> {
    Continue(CodeCursor),
    Call(F),
    Return(R),
    Raise(A),
    Yield(Y),
    Interrupt(I),
}
The explicit result of executing exactly one decoded instruction.

Variants



Continue(CodeCursor)

Continue in the current frame at the supplied validated cursor.



Call(F)

Push a new guest frame. This is data interpreted by the loop, not a Rust call.



Return(R)

Pop the current guest frame and carry consumer-defined return data.



Raise(A)

Stop with a consumer-defined abrupt outcome.



Yield(Y)

Cooperatively yield consumer-defined state.



Interrupt(I)

Stop for a consumer-defined interrupt.