pub struct ContinuationEvidence<Id> { /* private fields */ }Expand description
Content-bound evidence for a suspended continuation and its receipt prefix.
Implementations
Sourceimpl<Id> ContinuationEvidence<Id>
impl<Id> ContinuationEvidence<Id>
Sourcepub fn content_id(&self) -> &ContentId
pub fn content_id(&self) -> &ContentId
Returns the admitted program identity to which this continuation belongs.
Sourcepub fn receipt(&self) -> &WorkReceipt<Id>
pub fn receipt(&self) -> &WorkReceipt<Id>
Returns all work observed before suspension.