Frame

Struct Frame 

pub struct Frame<P, K, R, H>{ /* private fields */ }
One admitted activation, composed entirely from bounded machine state.

Implementations

Source

impl<P, K, R, H> Frame<P, K, R, H>

pub fn new( slot_limit: AdmissionLimit, operand_limit: WorkLimit, cursor: CodeCursor, continuation: Option<K>, roots: R, handlers: H, ) -> Self

Composes a frame at a validated code cursor with independently bounded storage.

pub fn slots(&self) -> &SlotFile<P>

Returns the bounded local-slot file.

pub fn slots_mut(&mut self) -> &mut SlotFile<P>

Returns the mutable bounded local-slot file.

pub fn operands(&self) -> &UnitStack<P>

Returns the bounded operand stack.

pub fn operands_mut(&mut self) -> &mut UnitStack<P>

Returns the mutable bounded operand stack.

pub fn cursor(&self) -> CodeCursor

Returns the current validated instruction cursor.

pub fn set_cursor(&mut self, cursor: CodeCursor)

Moves the frame to another validated instruction cursor.

pub fn continuation(&self) -> Option<&K>

Returns the caller-defined continuation state.

pub fn roots(&self) -> &R

Returns the caller-defined managed-root state.

pub fn roots_mut(&mut self) -> &mut R

Returns the mutable caller-defined managed-root state.

pub fn handlers(&self) -> &H

Returns the caller-defined handler state.

pub fn handlers_mut(&mut self) -> &mut H

Returns the mutable caller-defined handler state.