pub struct LocatedInstruction<I, Id> { /* private fields */ }Expand description
A decoded instruction and all immutable metadata required before execution.
Implementations
Sourceimpl<I, Id> LocatedInstruction<I, Id>
impl<I, Id> LocatedInstruction<I, Id>
Sourcepub fn new(
instruction: I,
id: Id,
location: SourceLocation,
safepoint: bool,
coverage: Option<CoverageMetadata>,
) -> Self
pub fn new( instruction: I, id: Id, location: SourceLocation, safepoint: bool, coverage: Option<CoverageMetadata>, ) -> Self
Prepares one instruction. Its identity is checked against the policy while code is frozen.
Sourcepub fn instruction(&self) -> &I
pub fn instruction(&self) -> &I
Returns the decoded instruction.
Sourcepub fn location(&self) -> &SourceLocation
pub fn location(&self) -> &SourceLocation
Returns its source location.
Sourcepub fn is_safepoint(&self) -> bool
pub fn is_safepoint(&self) -> bool
Returns whether this is a semantic safepoint.
Sourcepub fn coverage(&self) -> Option<CoverageMetadata>
pub fn coverage(&self) -> Option<CoverageMetadata>
Returns the optional stable coverage-counter metadata.