pub struct MachinePermit { /* private fields */ }Expand description
Proof that one exact immutable machine description passed admission.
Implementations
Sourceimpl MachinePermit
impl MachinePermit
Sourcepub fn admit<P, M, A>(
description: &MachineDescription<'_, P, M>,
) -> Result<Self, AdmissionError<A::Refusal>>
pub fn admit<P, M, A>( description: &MachineDescription<'_, P, M>, ) -> Result<Self, AdmissionError<A::Refusal>>
Validates the complete description and mints its content-bound permit.
Sourcepub fn content_id(&self) -> &ContentId
pub fn content_id(&self) -> &ContentId
Returns the kernel content identity admitted by this permit.
Sourcepub fn accepts<P, M, A>(
&self,
description: &MachineDescription<'_, P, M>,
) -> bool
pub fn accepts<P, M, A>( &self, description: &MachineDescription<'_, P, M>, ) -> bool
Returns whether this permit binds exactly the supplied description.