pub struct RootSnapshot { /* private fields */ }Expand description
A complete, ordered view of roots visible at one machine safepoint.
Implementations
Sourceimpl RootSnapshot
impl RootSnapshot
Sourcepub fn scan(
source: &impl ManagedRootSource,
budget: WorkLimit,
) -> Result<Self, RootScanError>
pub fn scan( source: &impl ManagedRootSource, budget: WorkLimit, ) -> Result<Self, RootScanError>
Materializes all roots atomically or returns exact budget exhaustion.