pub struct Frame<P, K, R, H>where
P: ValueWidthPolicy,{ /* private fields */ }Expand description
One admitted activation, composed entirely from bounded machine state.
Implementations
Sourceimpl<P, K, R, H> Frame<P, K, R, H>where
P: ValueWidthPolicy,
impl<P, K, R, H> Frame<P, K, R, H>where
P: ValueWidthPolicy,
Sourcepub fn new(
slot_limit: AdmissionLimit,
operand_limit: WorkLimit,
cursor: CodeCursor,
continuation: Option<K>,
roots: R,
handlers: H,
) -> Self
pub fn new( slot_limit: AdmissionLimit, operand_limit: WorkLimit, cursor: CodeCursor, continuation: Option<K>, roots: R, handlers: H, ) -> Self
Composes a frame at a validated code cursor with independently bounded storage.
Sourcepub fn operands_mut(&mut self) -> &mut UnitStack<P>
pub fn operands_mut(&mut self) -> &mut UnitStack<P>
Returns the mutable bounded operand stack.
Sourcepub fn cursor(&self) -> CodeCursor
pub fn cursor(&self) -> CodeCursor
Returns the current validated instruction cursor.
Sourcepub fn set_cursor(&mut self, cursor: CodeCursor)
pub fn set_cursor(&mut self, cursor: CodeCursor)
Moves the frame to another validated instruction cursor.
Sourcepub fn continuation(&self) -> Option<&K>
pub fn continuation(&self) -> Option<&K>
Returns the caller-defined continuation state.
Sourcepub fn handlers_mut(&mut self) -> &mut H
pub fn handlers_mut(&mut self) -> &mut H
Returns the mutable caller-defined handler state.